class Swiftlint < Formula
  desc "Tool to enforce Swift style and conventions"
  homepage "https://github.com/realm/SwiftLint"
  url "https://github.com/realm/SwiftLint.git",
      tag:      "0.55.1",
      revision: "b515723b16eba33f15c4677ee65f3fef2ce8c255"
  license "MIT"
  head "https://github.com/realm/SwiftLint.git", branch: "main"

  depends_on xcode: "8.0"

  uses_from_macos "swift"

  on_sonoma :or_newer do
    depends_on xcode: ["15.3", :build]
  end
  on_ventura :or_older do
    depends_on "swift" => :build
  end

  def install
    system "swift", "build", "--disable-sandbox", "--configuration", "release", "--product", "swiftlint"
    bin.install ".build/release/swiftlint"
    generate_completions_from_executable(bin/"swiftlint", "--generate-completion-script")
  end

  test do
    (testpath/"Test.swift").write "import Foundation"
    assert_match "Test.swift:1:1: warning: Trailing Newline Violation: " \
                 "Files should have a single trailing newline (trailing_newline)",
      shell_output("SWIFTLINT_SWIFT_VERSION=3 SWIFTLINT_DISABLE_SOURCEKIT=1 #{bin}/swiftlint lint --no-cache").chomp
    assert_match version.to_s,
      shell_output("#{bin}/swiftlint version").chomp
  end
end
